library(tidyverse)
library(here)
library(readxl)

##
REPODIR = here::here()

##
allsamples.file <- "/home/mh/Dropbox/phd_project/Papers_writing/SysMetEx_dataset_paper/201809_sysmetex_dataset/Consolidated_Lists_2018-04-03_MH.xlsx"
excel_sheets(allsamples.file)
allsamples <- read_excel(allsamples.file,
  sheet="Biosamples") %>%
  drop_na(`Sample ID`)

## parse proteomics
# pp <- read_tsv(paste(REPODIR,"Tables/lfqs_merged_uploaded.tsv",sep="/"))
# pp <- pp %>%
#   mutate(SampleID = gsub("ST-","-", data_files)) %>% #manually correct AXX reseq
#   mutate(SampleID = gsub("^\\s|\\s$","",SampleID)) %>% #remove trailing and leading whitespaces
#   mutate(SampleID = gsub("\\s","-",SampleID)) %>% #replace whitespaces with hyphens
#   mutate(SampleID = gsub("UDE-SLX7-7A-M-M-Pr","UDE-SLX7-7A-M-B-Pr", SampleID)) %>% #manually correct UDE-SLX7-7A-M-M-Pr
#   mutate(SampleID = gsub("((LNU|UDE)-[ASLX]+\\d*-[^\\-]+(-[^\\-]+)*-[MP]-B\\d*)-(Pr)*.*","\\1", SampleID)) %>%
#   select(SampleID, everything()) %>%
#   mutate(SampleID = gsub("_2uL$","",SampleID))
# 
# tmp.out <- pp %>%
#   mutate(SampleID = ifelse(!SampleID %in% allsamples$`Sample ID`,paste("FIX_",SampleID), SampleID))
# 
# write_tsv(tmp.out, path=paste(REPODIR, "Tables/lfqs_uploaded_sampleIDs.tsv", sep="/"))

pp <-read_tsv(paste(REPODIR,"Tables/lfqs_uploaded_sampleIDs_fixed.csv", sep="/"))
#any(!pp$SampleID %in% allsamples$`Sample ID`) #all accounted for


### RNAseq table
# rr <- read_tsv(paste(REPODIR, "Tables/RNAseq_samples_ENA.tsv", sep="/"))
# rr <- rr %>%
#   mutate(RNA_SampleID = SampleID) %>%
#   mutate(SampleID = gsub("-R\\d*$","",RNA_SampleID)) %>%
#   select(SampleID, RNA_SampleID, everything()) %>%
#   mutate(SampleID = gsub("LNU-([ASLX]{2}[LX])-","LNU-\\19-",SampleID))
# 
# rr$SampleID[!rr$SampleID %in% allsamples$`Sample ID`]
# 
# tmp.out <- rr %>%
#   mutate(SampleID = ifelse(!SampleID %in% allsamples$`Sample ID`,paste("FIX_",SampleID), SampleID))
# write_tsv(tmp.out, path=paste(REPODIR, "Tables/RNAseq_samples_ENA_SampleIDs.tsv", sep="/"))

rr <- read_tsv(paste(REPODIR, "Tables/RNAseq_samples_ENA_SampleIDs_fixed.csv", sep="/"))
#any(!rr$SampleID %in% allsamples$`Sample ID`)


## 
rr1 <- rr %>% 
  select(SampleID, Condition, Mixture) %>%
  mutate(Type="RNAseq")

pp1 <- pp %>%
  select(SampleID, Condition, Mixture=Inoculum) %>%
  mutate(Type="Proteomics")

#### Stats
merged <- bind_rows(rr1,pp1) %>%
  mutate(RNA_sample = ifelse(SampleID %in% rr1$SampleID , 1, 0 ),
         Prot_sample = ifelse(SampleID %in% pp1$SampleID , 1, 0 ))  %>% 
  group_by(SampleID, Condition, Mixture) %>%
  summarise(RNA_sample = max(RNA_sample),
            Prot_sample = max(Prot_sample)) %>%
  mutate(appears_in_both = ifelse(SampleID %in% intersect(pp1$SampleID, rr1$SampleID), 1, 0))


merged %>%
  ungroup() %>%
  mutate(Mixture = map_chr(Mixture, function(x) {paste(sort(unlist(str_split(x,""))),collapse="")})) %>%
  group_by(Condition, Mixture) %>%
  summarise(RNA = sum(RNA_sample),
            Prot = sum(Prot_sample),
            Both = sum(appears_in_both)) -> overview

merged %>%
  ungroup() %>%
  mutate(Species = 
           ifelse(grepl("ASL|SAL|LSA|LAS|ALS|SLA",Mixture),"tertiary", 
            ifelse(grepl("[ASL]XX",Mixture), "single", "binary"))) %>% 
  group_by(Condition, Species) %>%
  summarise(RNA = sum(RNA_sample),
            Prot = sum(Prot_sample),
            Both = sum(appears_in_both)) -> overview2

## write out
write_tsv(merged, path=paste(REPODIR, "Tables/Samples_overview_RNA-Prot-SampleIDs.tsv", sep="/"))
write_tsv(overview, path=paste(REPODIR, "Tables/Samples_overview_inoculum.tsv", sep="/"))
write_tsv(overview2, path=paste(REPODIR, "Tables/Samples_overview_simple.tsv", sep="/"))







